

from typing import Callable
from gaia_sdk.api.VariableRegistry import VariableRegistry


from dataclasses import dataclass


@dataclass
class UpdateIntent():
    """
    The specification to update an intent instance
    """

    identityId: str
    reference: str
    qualifier: str
    appendent: str
    utterance: dict
    labellist: dict
    version: str

